from pydantic_settings import BaseSettings, SettingsConfigDict


class Settings(BaseSettings):
    model_config = SettingsConfigDict(env_prefix="product_source_")

    tablename: str
    region_name: str = "us-east-1"
    indexname: str
    ident_code: str
    ident_key: str



from rooms_shared_services.src.models.texts.translations import Language, TextTranslations
from rooms_shared_services.src.translation.providers.abstract import AbstractTranslationProvider


class TranslationClient(object):
    def __init__(self, provider: AbstractTranslationProvider) -> None:
        """Set provider.

        Args:
            provider (AbstractTranslationProvider): _description_
        """
        self.provider = provider

    def bulk_translate(self, source_language: Language, target_languages: list[Language], txt: str) -> TextTranslations:
        translations = [
            self.provider.translate(txt=txt, source=source_language, target=target_language)
            for target_language in target_languages
        ]
        text_translations = TextTranslations(source=source_language)
        for target_language, translation in zip(target_languages, translations):
            setattr(text_translations, target_language.name, translation)
        return text_translations



import boto3
from mypy_boto3_translate import TranslateClient

from rooms_shared_services.src.models.texts.languages import Language
from rooms_shared_services.src.translation.providers.abstract import AbstractTranslationProvider

client: TranslateClient = boto3.client("translate")


class AWSTranslationProvider(AbstractTranslationProvider):
    def translate(self, txt: str, source: Language, target: Language):
        if source == target:
            return txt
        print("Starting translation: text {}, source {}, target {}".format(txt, source, target))
        resp = client.translate_text(Text=txt, SourceLanguageCode=source.name, TargetLanguageCode=target.name)
        return resp["TranslatedText"]
